__copyright__ = """
Copyright (c) 2005, Henry Ludemann
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

 * Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

 * Neither the name of the organization nor the names of its contributors
   may be used to endorse or promote products derived from this software
   without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""

class Flag:
    "Class to hold information about a command line flag"
    
    def __init__(self, short_flag, long_flag, description, param_name, 
            argument = None):
        """Construct a flag object

        Arguments
        short_flag -- A single character representing the 'short' command
        line option. Can be None if no short flag will be used.
        long_flag -- A string representing the 'long' command line option.
        Can be None if no long flag will be used.
        description -- Description of what this flag does
        param_name -- Parameter to be set to the result of this flag
        argument -- An optional Argument object, if the flag takes an
        argument
        """
        self.short_flag = short_flag
        self.long_flag = long_flag
        self.description = description
        self.param_name = param_name
        self.argument = argument

    def is_flag(self, flagText):
        """Does this flag match a given flag string"""
        if self.short_flag and "-" + self.short_flag == flagText:
            return 1
        if self.long_flag and "--" + self.long_flag == flagText:
            return 1
        return 0
        
    def get_value(self, argValue):
        """Get the value of the parameter, given that the flag has been set.

        argValue is the value given to the flag, or null if it doesn't have
        one.
        """
        if self.argument == None:
            # This argument doesn't take a parameter, so take the flags 
            # presence to mean the flags value is true.
            if (argValue is not None) and (argValue != ""):
                raise ValueError, "Flag %s recieved argument %s when it " \
                    "didn't expect one!"%(str(self), str(argValue))
            return True
        else:
            return self.argument.get_value(argValue)

    def get_param_name(self):
        """Get the name of the parameter this flag sets"""
        return self.param_name

    def get_flag_name(self):
        """Get the name of a flag

        If the short name exists, it returns that. Otherwise returns the long 
        flag.
        """
        if self.short_flag:
            return self.short_flag
        return self.long_flag

    def __str__(self):
        if self.short_flag and self.long_flag:
            result = '-%s, --%s'%(self.short_flag, self.long_flag)
        elif self.short_flag:
            result = '-%s'      %(self.short_flag)
        else:
            result = '    --%s'%(self.long_flag)

        # If we have an argument, add it to the string
        if self.argument:
            if self.long_flag:
                result = "%s=%s"%(result, self.argument.get_name())
            else:
                result = "%s %s"%(result, self.argument.get_name())
        return result
