__copyright__ = """
Copyright (c) 2005, Henry Ludemann
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

 * Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

 * Neither the name of the organization nor the names of its contributors
   may be used to endorse or promote products derived from this software
   without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""

import sys
import os
from StringIO import StringIO

def get_lines(text, width=80, offset=0, first_offset=0, linesep=os.linesep):
    """Print lines such that words feed onto the next line.
    
    Can set the width of the lines, the x offset of the lines, and the
    amount to offset on a standard line
    """
    output = StringIO()

    current_offset = first_offset
    while len(text) > 0:
        text = text.strip()

        # How much whitespace do we need to get at least to the offset?
        whitespace = offset - current_offset
        if whitespace < 0:
            whitespace = 0

        # How much space is remaining on this line?
        if current_offset > offset:
            space_remaining = width - current_offset
        else:
            space_remaining = width - offset

        if len(text) > space_remaining:
            # This line will not fit on the line, so we need to cut it in two
            lastWord = text.rfind(' ', 0, space_remaining)
            if lastWord == -1:
                # We couldn't find any whitespace; so use the whole word
                current_line = text[:space_remaining]
            else:
                # We found a space; stop writing this line after that word
                current_line = text[:lastWord]

            text = text[len(current_line):].strip()
            current_line = current_line.strip()
        else:
            # It all fits on this line
            current_line = text
            text = ""
        # Print out the whitespace preceding this line
        output.write(' ' * whitespace)

        # Print out this line, with a new line character
        output.write( current_line + linesep)
        current_offset = 0

    return output.getvalue()
