__copyright__ = """
Copyright (c) 2005, Henry Ludemann
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

 * Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

 * Neither the name of the organization nor the names of its contributors
   may be used to endorse or promote products derived from this software
   without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""

import unittest
from StringIO import StringIO

from cmdline.MultipleLines import get_lines

class MultipleLines_test(unittest.TestCase):
    def test_basic_output(self):
        "Test basic output"
        result = get_lines("Blah blah blah", linesep = '\n')
        self.assertEquals("Blah blah blah\n", result)
    
    def test_multiple_line_output(self):
        "Test that it feeds over multiple lines correctly"
        result = get_lines("Blah blah blah", width=10, linesep='\n')
        self.assertEquals("Blah blah\nblah\n", result)

    def test_initial_offset(self):
        "Test that it handles the initial offset correctly"
        result = get_lines("Blah blah blah", first_offset=5, width=10, 
                           linesep='\n')
        self.assertEquals("Blah\nblah blah\n", result)
        
    def test_offset(self):
        "Test that it deals with the offset correctly"
        result = get_lines("Blah blah blah", offset=5, width=10, linesep='\n')
        self.assertEquals("     Blah\n     blah\n     blah\n", result)

    def test_long_line(self):
        "Test that long words are dealt with correctly"
        result = get_lines("0123456789", width=6, linesep='\n')
        self.assertEquals("012345\n6789\n", result)
